.. currentmodule:: pyhomogenize

pyhomogenize's attributes
-------------------------

.. automethod:: basics.fmt

.. automethod:: basics.calendar

.. automethod:: basics.frequency

.. automethod:: netcdf_basics.files

.. automethod:: netcdf_basics.ds

.. automethod:: netcdf_basics.name

.. automethod:: time_control.time

.. automethod:: time_control.frequency

.. automethod:: time_control.time_fmt

.. automethod:: time_control.equalize

.. automethod:: time_control.calendar

.. automethod:: time_compare.compare_objects

.. automethod:: time_compare.time_control_objects

.. automethod:: time_compare.time
